Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(96)

Unified Diff: src/compiler/interpreter-assembler.h

Issue 1442643009: Rename original constructor to new target (Closed) Base URL: https://chromium.googlesource.com/v8/v8.git@master
Patch Set: rebase Created 5 years, 1 month ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/arm64/interface-descriptors-arm64.cc ('k') | src/compiler/interpreter-assembler.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/interpreter-assembler.h
diff --git a/src/compiler/interpreter-assembler.h b/src/compiler/interpreter-assembler.h
index 65955a92ba205a915dfe934409697951a16cbc12..562bbeedceb9203e192d2e4eaf5b706726b1431f 100644
--- a/src/compiler/interpreter-assembler.h
+++ b/src/compiler/interpreter-assembler.h
@@ -105,11 +105,11 @@ class InterpreterAssembler {
// Call constructor |constructor| with |arg_count| arguments (not
// including receiver) and the first argument located at
// |first_arg|. The |original_constructor| is the same as the
// |constructor| for the new keyword, but differs for the super
// keyword.
- Node* CallConstruct(Node* original_constructor, Node* constructor,
- Node* first_arg, Node* arg_count);
+ Node* CallConstruct(Node* new_target, Node* constructor, Node* first_arg,
+ Node* arg_count);
// Call JSFunction or Callable |function| with |arg_count|
// arguments (not including receiver) and the first argument
« no previous file with comments | « src/arm64/interface-descriptors-arm64.cc ('k') | src/compiler/interpreter-assembler.cc » ('j') | no next file with comments »
@@ -105,11 +105,11 @@ class InterpreterAssembler {
// Call constructor |constructor| with |arg_count| arguments (not
// including receiver) and the first argument located at
- // |first_arg|. The |original_constructor| is the same as the
+ // |first_arg|. The |new_target| is the same as the
// |constructor| for the new keyword, but differs for the super
// keyword.

Powered by Google App Engine
This is Rietveld 408576698